@@ -394,8 +394,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     @classmethod
     def get_aliases(cls: T.Type[ThisResolverType]) -> T.Set[str]:
-        node = cls._node
-        return {field.alias for field in node.__fields__.values()}
+        return cls._node.get_aliases()
 
     def parse_nested_obj(
         self, raw_d: dict, error_for_extra_fields: bool = False
